<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>dde::network::DockContentWidget</name>
    <message>
        <source>Network settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Detection</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP-Konflikt</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Proxy-Passwort</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>Gruppenpasswort</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Name (SSID)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Verbinden</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Kabelgebundene Verbindung deaktivieren</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kabelgebundene Verbindung aktivieren</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Drahtlosverbindung deaktivieren</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Drahtlosverbindung aktivieren</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netzwerk deaktivieren</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netzwerk aktivieren</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netzwerkeinstellungen</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Netzwerk aus</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netzwerkkabel abgezogen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nicht verbunden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Wird verbunden</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbunden, aber kein Internetzugang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbindung fehlgeschlagen</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-Konflikt</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 verbunden</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Kabelgebundenes Netzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Drahtlosnetzwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Mit verstecktem Netzwerk verbinden</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Meine Netzwerke</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Andere Netzwerke</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
</TS>